#! /usr/bin/env python3

import sys

sys.path.insert(1, '../../../../scripts')

from readMCD import readMCD

def printUsageAndExit() :
  print("USAGE : %s mcd column_1.txt columns_2.txt..."%sys.argv[0], file=sys.stderr)
  exit(1)

if __name__ == "__main__" :

  sys.stdout = open(1, 'w', encoding='utf-8', closefd=False)

  if len(sys.argv) < 3 :
    printUsageAndExit()

  conllMCD, conllMCDr = readMCD(sys.argv[1])

  for colFile in sys.argv[2:] :
    numCol = int(colFile.split('.')[0].split('_')[-1]) -1
    if not numCol in conllMCD :
      continue
    nameCol = conllMCD[numCol]

    if nameCol == "UPOS" :
      output = open("tagger.ts", 'w', encoding='utf-8')
      for line in open(colFile, "r", encoding='utf-8') :
        striped = line.strip()
        if len(striped) == 0 :
          continue
        print("<tagger> WRITE b.0 UPOS " + striped, file=output)
      output.close()

    elif nameCol == "XPOS" :
      output = open("taggerx.ts", 'w', encoding='utf-8')
      for line in open(colFile, "r", encoding='utf-8') :
        striped = line.strip()
        if len(striped) == 0 :
          continue
        print("WRITE b.0 XPOS " + striped, file=output)
      output.close()

    elif nameCol == "FEATS" :
      output = open("morpho_whole.ts", 'w', encoding='utf-8')
      for line in open(colFile, "r", encoding='utf-8') :
        striped = line.strip()
        if len(striped) == 0 :
          continue
        print("<morpho> WRITE b.0 FEATS " + striped, file=output)
      output.close()
      output = open("morpho_parts.ts", 'w', encoding='utf-8')
      allParts = set()
      allPartsList = []
      for line in open(colFile, "r", encoding='utf-8') :
        striped = line.strip()
        if len(striped) == 0 :
          continue
        parts = striped.split('|')
        for part in parts :
          allParts.add(part)
      for part in allParts :
        allPartsList.append(part)
      allPartsList.sort()
      for part in allPartsList :
        print("<morpho> ADD b.0 FEATS " + part, file=output)
      print("<morpho> NOTHING", file=output)
      output.close()

    elif nameCol == "DEPREL" :
      output = open("parser_eager_rel_strict.ts", 'w', encoding='utf-8')
      print("<parser> REDUCE_strict", file=output)
      labels = set()
      labelsList = []
      for line in open(colFile, "r", encoding='utf-8') :
        striped = line.strip()
        if len(striped) == 0 or striped == "root" or striped == "_" :
          continue
        label = striped
        if label not in labels :
          labels.add(striped)
          labelsList.append(striped)
      labelsList.sort()
      for label in labelsList :
        print("<parser> eager_LEFT_rel " + label, file=output)
        print("<parser> eager_RIGHT_rel " + label, file=output)
      print("<parser> eager_SHIFT", file=output)
      output.close()

      output = open("parser_eager_rel_relaxed.ts", 'w', encoding='utf-8')
      print("<parser> REDUCE_relaxed", file=output)
      for label in labelsList :
        print("<parser> eager_LEFT_rel " + label, file=output)
        print("<parser> eager_RIGHT_rel " + label, file=output)
      print("<parser> eager_SHIFT", file=output)
      output.close()

      output = open("parser_eager_strict.ts", 'w', encoding='utf-8')
      print("<parser> REDUCE_strict", file=output)
      print("<parser> eager_LEFT", file=output)
      print("<parser> eager_RIGHT", file=output)
      print("<parser> eager_SHIFT", file=output)
      output.close()

      output = open("parser_eager_relaxed.ts", 'w', encoding='utf-8')
      print("<parser> REDUCE_relaxed", file=output)
      print("<parser> eager_LEFT", file=output)
      print("<parser> eager_RIGHT", file=output)
      print("<parser> eager_SHIFT", file=output)
      output.close()

      output = open("parser_standard_rel.ts", 'w', encoding='utf-8')
      for label in labelsList :
        print("<parser> standard_LEFT_rel " + label, file=output)
        print("<parser> standard_RIGHT_rel " + label, file=output)
      print("<parser> standard_SHIFT", file=output)
      output.close()

      output = open("parser_standard.ts", 'w', encoding='utf-8')
      print("<parser> standard_LEFT_rel", file=output)
      print("<parser> standard_RIGHT_rel", file=output)
      print("<parser> standard_SHIFT", file=output)
      output.close()

      output = open("deprel.ts", 'w', encoding='utf-8')
      for label in labelsList :
        print("deprel " + label, file=output)
      output.close()

